
Classes API
-----------


.. autoclass:: schemdraw.elements.Element
    :members: add_label, get_bbox


.. autoclass:: schemdraw.elements.Element2Term


.. autoclass:: schemdraw.Drawing
    :members:
